# frozen_string_literal: true

require 'jekyll/page'
require_relative 'helper'
require_relative 'version'

module Jekyll
  module ActivityPub
    # Points to site's metadata
    class Instance < Jekyll::Page
      include Helper

      # Initialize with default data
      #
      # @param :site [Jekyll::Site]
      # @param :base [String]
      # @param :dir [String]
      # @param :name [String]
      def initialize(site, base = '', dir = 'api/v2', name = 'instance')
        @context = StubContext.new(registers: { site: site })

        super(site, base, dir, name)

        trigger_hooks :post_init
      end

      def permalink
        'api/v2/instance/'
      end

      def output_ext
        '.json'
      end

      def read_yaml(*)
        self.data = {
          'domain' => hostname,
          'version' => Jekyll::ActivityPub::VERSION,
          'source_url' => 'https://0xacab.org/sutty/jekyll/jekyll-activity-pub',
          'title' => public_name,
          'description' => summary,
          'usage' => {
            'users' => {
              'active_month' => 1
            }
          },
          'thumbnail' => {
            'url' => conditional_absolute_url(avatar)
          },
          'languages' => languages,
          'configuration' => {
            'urls' => {},
            'accounts' => {},
            'statuses' => {},
            'media_attachments' => {},
            'polls' => {},
            'translation' => {},
          },
          'registrations' => {
            'enabled' => false,
            'approval_required' => false,
            'message' => nil
          },
          'contact' => {
            'email' => email,
            'account' => {
              'id' => 1,
              'username' => username,
              'acct' => username,
              'display_name' => public_name,
              'locked' => false,
              'bot' => false,
              'discoverable' => true,
              'group' => false,
              'created_at' => published.xmlschema,
              'note' => summary,
              'url' => site.config['url'],
              'avatar' => conditional_absolute_url(avatar),
              'avatar_static' => conditional_absolute_url(avatar),
              'header' => conditional_absolute_url(header),
              'header_static' => conditional_absolute_url(header),
              'followers_count' => 0,
              'following_count' => 0,
              'statuses_count' => 0,
              'last_status_at' => nil,
              'noindex' => false,
              'emojis' => [],
              'fields' => []
            },
            'rules' => []
          }
        }
      end

      private

      # @return [String,nil]
      def header
        @header ||= [find_best_value_for(site.config, %w[activity_pub images], %w[image path])].flatten.compact.first
      end

      # @return [Array<String>]
      def languages
        @languages ||= site.config['locales'] || [locale]
      end

      # @return [String,nil]
      def email
        @email ||= find_best_value_for(site.config, %w[activity_pub email], 'email')
      end

      def avatar
        @avatar ||= [find_best_value_for(site.config, %w[activity_pub icons], 'logo')].flatten.compact.first
      end
    end
  end
end
